PartitionEntry

Struct PartitionEntry 

pub struct PartitionEntry { /* private fields */ }
Represents a single partition entry.

Implementations

Source

impl PartitionEntry

pub fn magic(&self) -> u16

The magic value of the entry.

pub fn raw_type(&self) -> u8

The partition type in raw representation.

pub fn raw_subtype(&self) -> u8

The partition sub-type in raw representation.

pub fn offset(&self) -> u32

Offset of the partition on flash.

pub fn len(&self) -> u32

Length of the partition in bytes.

pub fn is_empty(&self) -> bool

Checks for a zero-length partition.

pub fn label(&self) -> &[u8]

The label of the partition.

pub fn label_as_str(&self) -> &str

The label of the partition as &str.

pub fn flags(&self) -> u32

Raw flags of this partition. You probably want to use Self::is_read_only and Self::is_encrypted instead.

pub fn is_read_only(&self) -> bool

If the partition is read only.

pub fn is_encrypted(&self) -> bool

If the partition is encrypted.

This is the flag from the partition table. If flash encryption is enabled certain partition types are encrypted regardless of this.

pub fn partition_type(&self) -> PartitionType

The partition type (type and sub-type).

pub fn as_flash_region<'a, 'd>( self, flash: &'a mut FlashStorage<'d>, ) -> FlashRegion<'a, 'd>

Provides a “view” into the partition allowing to read/write the partition contents using the given FlashStorage.

pub fn sha256(&self, flash: &mut FlashStorage<'_>) -> Result<[u8; 32], Error>

Calculate the SHA-256 digest of this partition.

  • App / bootloader with appended hash: return that digest after verifying it
  • App / bootloader without appended hash: hash the image (not the whole partition)
  • Other types: hash the entire partition

For app images this is the validation hash (shown by esptool.py image-info), not the ELF file SHA-256 stored in crate::EspAppDesc.